@@ -1,14 +1,15 @@
 import os
 import socket
 import sys
-from StringIO import StringIO
+from io import StringIO
+import io
 from multiprocessing.pool import ThreadPool
 from threading import Thread
 
 import time
 from paramiko import SSHClient, AutoAddPolicy, RSAKey
 from paramiko.ssh_exception import NoValidConnectionsError
-from scpclient import Write, SCPError
+from scp import SCPClient, SCPException
 
 from cloudshell.cm.customscript.domain.cancellation_sampler import CancellationSampler
 from cloudshell.cm.customscript.domain.reservation_output_writer import ReservationOutputWriter
@@ -52,7 +53,7 @@ class LinuxScriptExecutor(IScriptExecutor):
             else:
                 raise Exception('Machine credentials are empty.')
         except NoValidConnectionsError as e:
-            error_code = next(e.errors.itervalues(), type('e', (object,), {'errno': 0})).errno
+            error_code = next(iter(e.errors.values()), type('e', (object,), {'errno': 0})).errno
             raise ExcutorConnectionError(error_code, e)
         except socket.error as e:
             raise ExcutorConnectionError(e.errno, e)
@@ -106,17 +107,19 @@ class LinuxScriptExecutor(IScriptExecutor):
         :type tmp_folder: str
         :type script_file: ScriptFile
         """
-        file_stream = StringIO(script_file.text)
-        file_size = len(file_stream.getvalue())
-        scp = None
+        scp = SCPClient(self.session.get_transport())
         try:
-            scp = Write(self.session.get_transport(), tmp_folder)
-            scp.send(file_stream, script_file.name, '0601', file_size)
-        except SCPError as e:
-            raise Exception,ErrorMsg.COPY_SCRIPT % str(e),sys.exc_info()[2]
+            fl = io.BytesIO()
+            fl.write(script_file.text.encode('utf-8'))
+            fl.seek(0)
+            remote_path = tmp_folder + '/' + script_file.name
+            scp.putfo(fl, remote_path=remote_path)
+        except SCPException as e:
+            raise Exception(ErrorMsg.COPY_SCRIPT % str(e)).with_traceback(sys.exc_info()[2])
         finally:
             if scp:
                 scp.close()
+                fl.close()
 
     def run_script(self, tmp_folder, script_file, env_vars, output_writer, print_output=True):
         """
@@ -127,7 +130,7 @@ class LinuxScriptExecutor(IScriptExecutor):
         :type print_output: bool
         """
         code = ''
-        for key, value in (env_vars or {}).iteritems():
+        for key, value in (env_vars or {}).items():
             code += 'export %s=%s;' % (key,self._escape(value))
         if self.target_host.password:
             code += 'export %s=%s;' % (self.PasswordEnvVarName, self._escape(self.target_host.password))
@@ -175,5 +178,5 @@ class LinuxScriptExecutor(IScriptExecutor):
         return async_result.get()
 
     def _escape(self, value):
-        escaped_str = "$'" + '\\x' + '\\x'.join([x.encode("hex") for x in str(value).encode("utf-8")]) + "'"
+        escaped_str = "$'" + '\\x' + '\\x'.join([str(x) for x in str(value).encode("utf-8")]) + "'"
         return escaped_str
\ No newline at end of file
